@@ -189,7 +189,20 @@ class S3ToLambda(
         :summary: Constructs a new instance of the S3ToLambda class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(S3ToLambda.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+                s3_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.S3EventSourceProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = S3ToLambdaProps(
@@ -270,7 +283,18 @@ class S3ToLambdaProps:
         if isinstance(s3_event_source_props, dict):
             s3_event_source_props = aws_cdk.aws_lambda_event_sources.S3EventSourceProps(**s3_event_source_props)
         if __debug__:
-            type_hints = typing.get_type_hints(S3ToLambdaProps.__init__)
+            def stub(
+                *,
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+                s3_event_source_props: typing.Optional[typing.Union[aws_cdk.aws_lambda_event_sources.S3EventSourceProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
             check_type(argname="argument existing_bucket_obj", value=existing_bucket_obj, expected_type=type_hints["existing_bucket_obj"])
             check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
